@@ -106,4 +106,4 @@ class DeployPod(Command):
         return super().completion(state)
 
     def help(self, _: ReplState):
-        return f'{DeployPod.COMMAND}\t deploy pod'
\ No newline at end of file
+        return f'{DeployPod.COMMAND}\t deploy Ops pod'
\ No newline at end of file
