@@ -169,10 +169,10 @@ class PostgresSession:
             except:
                 try:
                     # try with the ops pod
-                    pod_name = 'ops'
+                    pod_name = Config().get('pod.name', 'ops')
                     real_pod_name = Pods.get_with_selector(ns, label_selector = Config().get('pod.label-selector', 'run=ops')).metadata.name
                 except:
-                    log2(f"Could not locate {real_pod_name} pod.")
+                    log2(f"Could not locate {pod_name} pod.")
                     return None
 
             cmd = f'PGPASSWORD="{self.password()}" psql -h {self.endpoint()} -p {self.port()} -U {self.username()} {db} --pset pager=off -c "{sql}"'
